==> PyMandel-0.9.6.tar.gz: PyMandel-0.9.6/colormaps/metallic256_colormap.py <==
from numpy import array

'''
Colormap created by make_colormap utility from file metallic256.png
'''
metallic256 = array([ \
[27, 35, 42], [30, 37, 44], [32, 39, 45], [34, 41, 48],
[36, 42, 49], [36, 42, 49], [36, 43, 49], [37, 44, 50],
[37, 45, 51], [39, 45, 52], [41, 48, 55], [44, 51, 57],
[47, 54, 61], [50, 57, 64], [54, 61, 67], [57, 64, 70],
[61, 68, 75], [66, 73, 80], [70, 76, 83], [73, 80, 87],
[76, 84, 90], [79, 85, 93], [80, 87, 94], [81, 87, 95],
[81, 88, 94], [82, 87, 94], [83, 88, 94], [83, 89, 94],
[85, 88, 93], [86, 88, 92], [89, 89, 91], [91, 89, 90],
[94, 89, 89], [96, 89, 89], [99, 90, 87], [102, 90, 86],
[105, 90, 85], [106, 91, 84], [107, 91, 84], [108, 91, 84],
[107, 92, 84], [105, 92, 87], [101, 93, 92], [93, 94, 100],
[88, 96, 107], [84, 96, 111], [80, 97, 115], [77, 97, 119],
[74, 99, 122], [71, 98, 125], [70, 99, 127], [70, 99, 127],
[69, 100, 128], [70, 100, 128], [71, 100, 129], [72, 103, 131],
[75, 104, 133], [78, 106, 136], [81, 108, 139], [84, 111, 142],
[89, 114, 145], [93, 117, 150], [98, 121, 154], [103, 124, 158],
[107, 128, 163], [113, 132, 169], [121, 138, 176], [129, 145, 183],
[135, 149, 190], [141, 154, 195], [146, 157, 199], [149, 160, 203],
[151, 161, 204], [151, 162, 204], [152, 162, 204], [153, 164, 204],
[156, 165, 204], [158, 167, 203], [163, 170, 204], [166, 174, 203],
[171, 178, 203], [176, 182, 203], [182, 186, 203], [187, 190, 203],
[194, 195, 202], [199, 200, 202], [205, 205, 201], [210, 209, 201],
[216, 213, 201], [220, 217, 200], [225, 220, 200], [228, 224, 200],
[231, 226, 200], [234, 229, 199], [236, 230, 199], [237, 230, 200],
[238, 231, 199], [238, 231, 200], [237, 231, 200], [236, 230, 201],
[235, 229, 201], [233, 229, 202], [232, 228, 203], [230, 227, 205],
[228, 224, 207], [227, 224, 208], [224, 222, 209], [221, 220, 211],
[219, 218, 212], [218, 218, 214], [216, 216, 215], [215, 216, 216],
[215, 216, 216], [214, 215, 216], [213, 214, 215], [210, 211, 213],
[206, 208, 211], [201, 204, 208], [195, 198, 204], [189, 193, 199],
[182, 186, 195], [178, 182, 191], [174, 179, 189], [169, 175, 186],
[165, 171, 183], [161, 168, 181], [159, 165, 178], [155, 162, 177],
[153, 160, 175], [151, 158, 174], [149, 157, 172], [149, 156, 172],
[149, 156, 172], [148, 156, 172], [150, 157, 172], [151, 158, 174],
[153, 160, 175], [155, 162, 177], [158, 165, 179], [162, 168, 181],
[165, 171, 183], [169, 175, 186], [174, 179, 188], [178, 182, 191],
[182, 186, 195], [189, 192, 199], [195, 198, 204], [201, 203, 208],
[206, 208, 211], [210, 211, 214], [213, 214, 215], [214, 215, 216],
[214, 216, 217], [215, 216, 216], [216, 217, 215], [217, 218, 214],
[220, 219, 213], [221, 220, 212], [224, 222, 209], [227, 224, 208],
[228, 225, 206], [230, 226, 205], [232, 227, 204], [234, 228, 203],
[235, 229, 201], [237, 230, 200], [237, 231, 200], [238, 231, 199],
[237, 231, 200], [237, 231, 200], [236, 229, 199], [234, 228, 199],
[232, 226, 200], [228, 224, 200], [224, 220, 200], [220, 217, 201],
[215, 213, 201], [210, 209, 201], [205, 205, 201], [199, 200, 201],
[194, 195, 202], [188, 191, 202], [182, 186, 203], [176, 181, 203],
[170, 177, 203], [165, 173, 204], [162, 170, 203], [158, 167, 204],
[155, 165, 204], [153, 163, 204], [151, 161, 204], [151, 161, 204],
[151, 161, 204], [149, 159, 202], [145, 156, 198], [141, 153, 193],
[134, 148, 188], [127, 143, 182], [119, 138, 174], [111, 131, 167],
[106, 127, 162], [101, 123, 158], [97, 120, 153], [92, 116, 149],
[88, 114, 144], [83, 110, 141], [80, 108, 138], [78, 106, 135],
[75, 103, 133], [72, 102, 130], [71, 101, 129], [69, 100, 128],
[70, 99, 128], [70, 99, 127], [70, 99, 126], [72, 99, 124],
[74, 99, 122], [77, 98, 118], [81, 97, 114], [85, 96, 110],
[89, 95, 105], [95, 94, 98], [101, 92, 92], [105, 92, 87],
[108, 92, 84], [109, 91, 83], [108, 91, 84], [107, 91, 84],
[104, 91, 85], [102, 91, 86], [99, 90, 87], [96, 90, 88],
[94, 89, 90], [91, 89, 91], [89, 88, 92], [87, 88, 92],
[85, 88, 93], [84, 88, 93], [83, 88, 94], [81, 88, 94],
[81, 88, 94], [81, 88, 95], [80, 87, 94], [79, 85, 92],
[76, 83, 90], [73, 81, 87], [70, 77, 84], [65, 73, 80],
[61, 68, 75], [57, 64, 71], [53, 61, 68], [50, 57, 63],
[47, 53, 61], [44, 50, 57], [41, 48, 55], [39, 46, 53]])
'''
End of colormap from file metallic256.png
'''

==> PyMandel-1.0.8.tar.gz: PyMandel-1.0.8/colormaps/metallic256_colormap.py <==
from numpy import array

#****************************************************************************************
# 256-level colormap created by make_colormap utility from file metallic256.png
#****************************************************************************************
metallic256 = array([ \
[27, 35, 42], [30, 37, 44], [32, 39, 45], [34, 41, 48],
[36, 42, 49], [36, 42, 49], [36, 43, 49], [37, 44, 50],
[37, 45, 51], [39, 45, 52], [41, 48, 55], [44, 51, 57],
[47, 54, 61], [50, 57, 64], [54, 61, 67], [57, 64, 70],
[61, 68, 75], [66, 73, 80], [70, 76, 83], [73, 80, 87],
[76, 84, 90], [79, 85, 93], [80, 87, 94], [81, 87, 95],
[81, 88, 94], [82, 87, 94], [83, 88, 94], [83, 89, 94],
[85, 88, 93], [86, 88, 92], [89, 89, 91], [91, 89, 90],
[94, 89, 89], [96, 89, 89], [99, 90, 87], [102, 90, 86],
[105, 90, 85], [106, 91, 84], [107, 91, 84], [108, 91, 84],
[107, 92, 84], [105, 92, 87], [101, 93, 92], [93, 94, 100],
[88, 96, 107], [84, 96, 111], [80, 97, 115], [77, 97, 119],
[74, 99, 122], [71, 98, 125], [70, 99, 127], [70, 99, 127],
[69, 100, 128], [70, 100, 128], [71, 100, 129], [72, 103, 131],
[75, 104, 133], [78, 106, 136], [81, 108, 139], [84, 111, 142],
[89, 114, 145], [93, 117, 150], [98, 121, 154], [103, 124, 158],
[107, 128, 163], [113, 132, 169], [121, 138, 176], [129, 145, 183],
[135, 149, 190], [141, 154, 195], [146, 157, 199], [149, 160, 203],
[151, 161, 204], [151, 162, 204], [152, 162, 204], [153, 164, 204],
[156, 165, 204], [158, 167, 203], [163, 170, 204], [166, 174, 203],
[171, 178, 203], [176, 182, 203], [182, 186, 203], [187, 190, 203],
[194, 195, 202], [199, 200, 202], [205, 205, 201], [210, 209, 201],
[216, 213, 201], [220, 217, 200], [225, 220, 200], [228, 224, 200],
[231, 226, 200], [234, 229, 199], [236, 230, 199], [237, 230, 200],
[238, 231, 199], [238, 231, 200], [237, 231, 200], [236, 230, 201],
[235, 229, 201], [233, 229, 202], [232, 228, 203], [230, 227, 205],
[228, 224, 207], [227, 224, 208], [224, 222, 209], [221, 220, 211],
[219, 218, 212], [218, 218, 214], [216, 216, 215], [215, 216, 216],
[215, 216, 216], [214, 215, 216], [213, 214, 215], [210, 211, 213],
[206, 208, 211], [201, 204, 208], [195, 198, 204], [189, 193, 199],
[182, 186, 195], [178, 182, 191], [174, 179, 189], [169, 175, 186],
[165, 171, 183], [161, 168, 181], [159, 165, 178], [155, 162, 177],
[153, 160, 175], [151, 158, 174], [149, 157, 172], [149, 156, 172],
[149, 156, 172], [148, 156, 172], [150, 157, 172], [151, 158, 174],
[153, 160, 175], [155, 162, 177], [158, 165, 179], [162, 168, 181],
[165, 171, 183], [169, 175, 186], [174, 179, 188], [178, 182, 191],
[182, 186, 195], [189, 192, 199], [195, 198, 204], [201, 203, 208],
[206, 208, 211], [210, 211, 214], [213, 214, 215], [214, 215, 216],
[214, 216, 217], [215, 216, 216], [216, 217, 215], [217, 218, 214],
[220, 219, 213], [221, 220, 212], [224, 222, 209], [227, 224, 208],
[228, 225, 206], [230, 226, 205], [232, 227, 204], [234, 228, 203],
[235, 229, 201], [237, 230, 200], [237, 231, 200], [238, 231, 199],
[237, 231, 200], [237, 231, 200], [236, 229, 199], [234, 228, 199],
[232, 226, 200], [228, 224, 200], [224, 220, 200], [220, 217, 201],
[215, 213, 201], [210, 209, 201], [205, 205, 201], [199, 200, 201],
[194, 195, 202], [188, 191, 202], [182, 186, 203], [176, 181, 203],
[170, 177, 203], [165, 173, 204], [162, 170, 203], [158, 167, 204],
[155, 165, 204], [153, 163, 204], [151, 161, 204], [151, 161, 204],
[151, 161, 204], [149, 159, 202], [145, 156, 198], [141, 153, 193],
[134, 148, 188], [127, 143, 182], [119, 138, 174], [111, 131, 167],
[106, 127, 162], [101, 123, 158], [97, 120, 153], [92, 116, 149],
[88, 114, 144], [83, 110, 141], [80, 108, 138], [78, 106, 135],
[75, 103, 133], [72, 102, 130], [71, 101, 129], [69, 100, 128],
[70, 99, 128], [70, 99, 127], [70, 99, 126], [72, 99, 124],
[74, 99, 122], [77, 98, 118], [81, 97, 114], [85, 96, 110],
[89, 95, 105], [95, 94, 98], [101, 92, 92], [105, 92, 87],
[108, 92, 84], [109, 91, 83], [108, 91, 84], [107, 91, 84],
[104, 91, 85], [102, 91, 86], [99, 90, 87], [96, 90, 88],
[94, 89, 90], [91, 89, 91], [89, 88, 92], [87, 88, 92],
[85, 88, 93], [84, 88, 93], [83, 88, 94], [81, 88, 94],
[81, 88, 94], [81, 88, 95], [80, 87, 94], [79, 85, 92],
[76, 83, 90], [73, 81, 87], [70, 77, 84], [65, 73, 80],
[61, 68, 75], [57, 64, 71], [53, 61, 68], [50, 57, 63],
[47, 53, 61], [44, 50, 57], [41, 48, 55], [39, 46, 53]])
